@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: persistent-template
 version: 2.1.5
-id: persistent-template-2.1.5-8e80a31cb67cc3ef9d0a8d75e0beb774
-key: persi_5SC4flOyqRmDO6oU34Nasq
+id: persistent-template-2.1.5-843c6c1cb8c608f5d7b0340a1ba98852
+key: persi_L1sGdgfttEoLNheDOxYfGO
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
 stability: Stable
@@ -20,24 +20,24 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-template-2.1.5
 library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-template-2.1.5
 data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-template-2.1.5
-hs-libraries: HSpersistent-template-2.1.5-5SC4flOyqRmDO6oU34Nasq
+hs-libraries: HSpersistent-template-2.1.5-L1sGdgfttEoLNheDOxYfGO
 depends:
-    aeson-0.10.0.0-d37842f030fec47bc6e0ba2aef0f6571
-    aeson-compat-0.3.0.0-a20a161a51c55c8ab6017f045ab6c3e9
+    aeson-0.10.0.0-3aa334e096178e3f732c7fe0cfda35e7
+    aeson-compat-0.3.1.0-31f7363b7ec2a62ab03ab2396f0de1f2
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
     http-api-data-0.2.2-107631c0bae2e2a6211651e9a27c130c
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    monad-logger-0.3.18-2bfbe07c1c1cdc537fa81b345cec7330
+    monad-logger-0.3.18-1a8cc90bb0cf2afc03da9e875eb23203
     path-pieces-0.2.1-c4c6ea4593a7da7123f92fac6c85ebd3
-    persistent-2.2.4-3efd0b27ba9bd4f18bae3621104638b2
+    persistent-2.2.4-7bfa93ca2781b33384883da4115f96aa
     tagged-0.8.3-aa128de4449752177a05765fb0ce3959
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
+    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
 haddock-interfaces: /usr/share/doc/haskell-persistent-template/html/persistent-template.haddock
 haddock-html: /usr/share/doc/haskell-persistent-template/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
